# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class GenerationForecastApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def forecast_availability_daily_evolution_get(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution of the fourteen-day generation capacity forecast over time (FOU2T14D)  # noqa: E501

        This endpoint provides the evolution of all daily generation forecasts over time for a given Forecast Date.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_evolution_get(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
            return data

    def forecast_availability_daily_evolution_get_with_http_info(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution of the fourteen-day generation capacity forecast over time (FOU2T14D)  # noqa: E501

        This endpoint provides the evolution of all daily generation forecasts over time for a given Forecast Date.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_evolution_get_with_http_info(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_date', 'level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_daily_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'forecast_date' is set
        if ('forecast_date' not in params or
                params['forecast_date'] is None):
            raise ValueError("Missing the required parameter `forecast_date` when calling `forecast_availability_daily_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'forecast_date' in params:
            query_params.append(('forecastDate', params['forecast_date']))  # noqa: E501
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/daily/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_daily_get(self, **kwargs):  # noqa: E501
        """Fourteen-day generation capacity forecast (FOU2T14D)  # noqa: E501

        This endpoint provides the latest fourteen-day generation forecast  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_daily_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_daily_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_availability_daily_get_with_http_info(self, **kwargs):  # noqa: E501
        """Fourteen-day generation capacity forecast (FOU2T14D)  # noqa: E501

        This endpoint provides the latest fourteen-day generation forecast  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_daily_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/daily', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_daily_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the fourteen-day generation capacity forecast (FOU2T14D)  # noqa: E501

        This endpoint provides the latest fourteen-day generation forecast from a given DateTime  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_availability_daily_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the fourteen-day generation capacity forecast (FOU2T14D)  # noqa: E501

        This endpoint provides the latest fourteen-day generation forecast from a given DateTime  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_daily_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_daily_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_availability_daily_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/daily/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_summary14_d_get(self, **kwargs):  # noqa: E501
        """Down-sampled fourteen-day generation forecast (FOU2T14D)  # noqa: E501

        This endpoint provides a summary of generation forecast data aggregated by forecast date,  intended for visualisation purposes. Use other availability forecast endpoints for full dataset access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_summary14_d_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: list[InsightsApiModelsResponsesGenerationAggregatedForecast]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_summary14_d_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_summary14_d_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_availability_summary14_d_get_with_http_info(self, **kwargs):  # noqa: E501
        """Down-sampled fourteen-day generation forecast (FOU2T14D)  # noqa: E501

        This endpoint provides a summary of generation forecast data aggregated by forecast date,  intended for visualisation purposes. Use other availability forecast endpoints for full dataset access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_summary14_d_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: list[InsightsApiModelsResponsesGenerationAggregatedForecast]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_summary14_d_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/summary/14D', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsResponsesGenerationAggregatedForecast]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_summary3_yw_get(self, **kwargs):  # noqa: E501
        """Down-sampled three-year generation forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides a summary of generation forecast data aggregated by forecast date,  intended for visualisation purposes. Use other availability forecast endpoints for full dataset access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_summary3_yw_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: list[InsightsApiModelsResponsesGenerationAggregatedForecast]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_summary3_yw_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_summary3_yw_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_availability_summary3_yw_get_with_http_info(self, **kwargs):  # noqa: E501
        """Down-sampled three-year generation forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides a summary of generation forecast data aggregated by forecast date,  intended for visualisation purposes. Use other availability forecast endpoints for full dataset access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_summary3_yw_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: list[InsightsApiModelsResponsesGenerationAggregatedForecast]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_summary3_yw_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/summary/3YW', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsResponsesGenerationAggregatedForecast]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_weekly_evolution_get(self, year, week, **kwargs):  # noqa: E501
        """Evolution of the three-year generation capacity forecast over time (FOU2T3YW)  # noqa: E501

        This endpoint provides all weekly generation forecasts over time for a given Year and Week  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_evolution_get(year, week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: (required)
        :param int week: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_weekly_evolution_get_with_http_info(year, week, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_weekly_evolution_get_with_http_info(year, week, **kwargs)  # noqa: E501
            return data

    def forecast_availability_weekly_evolution_get_with_http_info(self, year, week, **kwargs):  # noqa: E501
        """Evolution of the three-year generation capacity forecast over time (FOU2T3YW)  # noqa: E501

        This endpoint provides all weekly generation forecasts over time for a given Year and Week  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_evolution_get_with_http_info(year, week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: (required)
        :param int week: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_weekly_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `forecast_availability_weekly_evolution_get`")  # noqa: E501
        # verify the required parameter 'week' is set
        if ('week' not in params or
                params['week'] is None):
            raise ValueError("Missing the required parameter `week` when calling `forecast_availability_weekly_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/weekly/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_weekly_get(self, **kwargs):  # noqa: E501
        """Three-year generation capacity forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides the latest three-year generation forecast  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_weekly_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_weekly_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_availability_weekly_get_with_http_info(self, **kwargs):  # noqa: E501
        """Three-year generation capacity forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides the latest three-year generation forecast  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_weekly_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/weekly', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_availability_weekly_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the three-year generation capacity forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides the latest three-year forecast from a given DateTime  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_availability_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_availability_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_availability_weekly_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the three-year generation capacity forecast (FOU2T3YW)  # noqa: E501

        This endpoint provides the latest three-year forecast from a given DateTime  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_availability_weekly_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str level:
        :param list[str] bm_unit:
        :param list[str] fuel_type:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'level', 'bm_unit', 'fuel_type', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_availability_weekly_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_availability_weekly_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'level' in params:
            query_params.append(('level', params['level']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/availability/weekly/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationAvailabilityWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_day_ahead_get(self, _from, to, **kwargs):  # noqa: E501
        """Day-ahead aggregated generation (DAG/B1430)  # noqa: E501

        This endpoint provides day-ahead aggregated generation data filtered by settlement date.                This API endpoint has a maximum range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_day_ahead_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadAggregatedGeneration
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_day_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_day_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_generation_day_ahead_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Day-ahead aggregated generation (DAG/B1430)  # noqa: E501

        This endpoint provides day-ahead aggregated generation data filtered by settlement date.                This API endpoint has a maximum range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_day_ahead_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadAggregatedGeneration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'settlement_period_from', 'settlement_period_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_day_ahead_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_day_ahead_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_day_ahead_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/day-ahead', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadAggregatedGeneration',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_and_solar_day_ahead_get(self, _from, to, process_type, **kwargs):  # noqa: E501
        """Day-ahead generation forecast for wind and solar (DGWS/B1440)  # noqa: E501

        This endpoint provides day-ahead forecast generation data for wind and solar.                This endpoint filters by startTime and provides a maximum data output range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_and_solar_day_ahead_get(_from, to, process_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str process_type: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadGenerationForWindAndSolar
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_and_solar_day_ahead_get_with_http_info(_from, to, process_type, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_and_solar_day_ahead_get_with_http_info(_from, to, process_type, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_and_solar_day_ahead_get_with_http_info(self, _from, to, process_type, **kwargs):  # noqa: E501
        """Day-ahead generation forecast for wind and solar (DGWS/B1440)  # noqa: E501

        This endpoint provides day-ahead forecast generation data for wind and solar.                This endpoint filters by startTime and provides a maximum data output range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_and_solar_day_ahead_get_with_http_info(_from, to, process_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str process_type: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadGenerationForWindAndSolar
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'process_type', 'settlement_period_from', 'settlement_period_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_and_solar_day_ahead_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_wind_and_solar_day_ahead_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_wind_and_solar_day_ahead_get`")  # noqa: E501
        # verify the required parameter 'process_type' is set
        if ('process_type' not in params or
                params['process_type'] is None):
            raise ValueError("Missing the required parameter `process_type` when calling `forecast_generation_wind_and_solar_day_ahead_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'process_type' in params:
            query_params.append(('processType', params['process_type']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind-and-solar/day-ahead', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadGenerationForWindAndSolar',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_earliest_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted wind generation (WINDFOR)  # noqa: E501

        This endpoint provides the eariest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_earliest_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_earliest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_earliest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_earliest_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted wind generation (WINDFOR)  # noqa: E501

        This endpoint provides the eariest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_earliest_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_earliest_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_wind_earliest_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_wind_earliest_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/earliest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_earliest_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted wind generation (WINDFOR) stream  # noqa: E501

        This endpoint provides the earliest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  This endpoint has an optimised JSON payload and is aimed at frequent requests for the wind generation forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_earliest_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: list[InsightsApiModelsServiceWindGenerationForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_earliest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_earliest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_earliest_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted wind generation (WINDFOR) stream  # noqa: E501

        This endpoint provides the earliest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  This endpoint has an optimised JSON payload and is aimed at frequent requests for the wind generation forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_earliest_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: list[InsightsApiModelsServiceWindGenerationForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_earliest_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_wind_earliest_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_wind_earliest_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/earliest/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsServiceWindGenerationForecastRow]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_evolution_get(self, start_time, **kwargs):  # noqa: E501
        """Evolution of the wind generation forecast over time (WINDFOR)  # noqa: E501

        This endpoint provides the evolution wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_evolution_get(start_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime start_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_evolution_get_with_http_info(start_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_evolution_get_with_http_info(start_time, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_evolution_get_with_http_info(self, start_time, **kwargs):  # noqa: E501
        """Evolution of the wind generation forecast over time (WINDFOR)  # noqa: E501

        This endpoint provides the evolution wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_evolution_get_with_http_info(start_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime start_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_time' is set
        if ('start_time' not in params or
                params['start_time'] is None):
            raise ValueError("Missing the required parameter `start_time` when calling `forecast_generation_wind_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_get(self, **kwargs):  # noqa: E501
        """Current wind generation forecast (WINDFOR)  # noqa: E501

        This endpoint provides the latest wind generation forecast data. This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30. Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_get_with_http_info(self, **kwargs):  # noqa: E501
        """Current wind generation forecast (WINDFOR)  # noqa: E501

        This endpoint provides the latest wind generation forecast data. This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30. Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the wind generation forecast (WINDFOR)  # noqa: E501

        This endpoint provides the historical wind generation forecast data. This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the wind generation forecast (WINDFOR)  # noqa: E501

        This endpoint provides the historical wind generation forecast data. This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_generation_wind_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_latest_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted wind generation (WINDFOR)  # noqa: E501

        This endpoint provides the latest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_latest_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_latest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_latest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_latest_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted wind generation (WINDFOR)  # noqa: E501

        This endpoint provides the latest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_latest_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_latest_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_wind_latest_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_wind_latest_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_latest_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted wind generation (WINDFOR) stream  # noqa: E501

        This endpoint provides the latest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  This endpoint has an optimised JSON payload and is aimed at frequent requests for the wind generation forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_latest_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: list[InsightsApiModelsServiceWindGenerationForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_latest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_latest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_latest_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted wind generation (WINDFOR) stream  # noqa: E501

        This endpoint provides the latest wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.  This endpoint has an optimised JSON payload and is aimed at frequent requests for the wind generation forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_latest_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :return: list[InsightsApiModelsServiceWindGenerationForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_latest_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_generation_wind_latest_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_generation_wind_latest_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/latest/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsServiceWindGenerationForecastRow]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_generation_wind_peak_get(self, **kwargs):  # noqa: E501
        """Peak wind generation forecast for each day (WINDFOR)  # noqa: E501

        This endpoint provides the peak wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_peak_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The start of the requested date range.
        :param date to: The end of the requested date range.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_generation_wind_peak_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_generation_wind_peak_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_generation_wind_peak_get_with_http_info(self, **kwargs):  # noqa: E501
        """Peak wind generation forecast for each day (WINDFOR)  # noqa: E501

        This endpoint provides the peak wind generation forecast data.  This provides wind generation forecast for wind farms which are visible to the ESO and have operational metering.  Updated data is published by NGESO up to 8 times a day at 03:30, 05:30, 08:30, 10:30, 12:30, 16:30, 19:30 and 23:30.  Results are filtered by a range of DateTime parameters.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_generation_wind_peak_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The start of the requested date range.
        :param date to: The end of the requested date range.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_generation_wind_peak_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/generation/wind/peak', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesGenerationWindGenerationForecast',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'start_time': 'datetime',
        'created_date_time': 'datetime',
        'bm_unit': 'str',
        'bm_unit_type': 'str',
        'lead_party_name': 'str',
        'national_grid_bm_unit': 'str',
        'bid_offer_pair_cashflows': 'InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs',
        'total_cashflow': 'float'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'start_time': 'startTime',
        'created_date_time': 'createdDateTime',
        'bm_unit': 'bmUnit',
        'bm_unit_type': 'bmUnitType',
        'lead_party_name': 'leadPartyName',
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'bid_offer_pair_cashflows': 'bidOfferPairCashflows',
        'total_cashflow': 'totalCashflow'
    }

    def __init__(self, settlement_date=None, settlement_period=None, start_time=None, created_date_time=None, bm_unit=None, bm_unit_type=None, lead_party_name=None, national_grid_bm_unit=None, bid_offer_pair_cashflows=None, total_cashflow=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._start_time = None
        self._created_date_time = None
        self._bm_unit = None
        self._bm_unit_type = None
        self._lead_party_name = None
        self._national_grid_bm_unit = None
        self._bid_offer_pair_cashflows = None
        self._total_cashflow = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if start_time is not None:
            self.start_time = start_time
        if created_date_time is not None:
            self.created_date_time = created_date_time
        if bm_unit is not None:
            self.bm_unit = bm_unit
        if bm_unit_type is not None:
            self.bm_unit_type = bm_unit_type
        if lead_party_name is not None:
            self.lead_party_name = lead_party_name
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if bid_offer_pair_cashflows is not None:
            self.bid_offer_pair_cashflows = bid_offer_pair_cashflows
        if total_cashflow is not None:
            self.total_cashflow = total_cashflow

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param start_time: The start_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def created_date_time(self):
        """Gets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_time

    @created_date_time.setter
    def created_date_time(self, created_date_time):
        """Sets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param created_date_time: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: datetime
        """

        self._created_date_time = created_date_time

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    @property
    def bm_unit_type(self):
        """Gets the bm_unit_type of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The bm_unit_type of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit_type

    @bm_unit_type.setter
    def bm_unit_type(self, bm_unit_type):
        """Sets the bm_unit_type of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param bm_unit_type: The bm_unit_type of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: str
        """

        self._bm_unit_type = bm_unit_type

    @property
    def lead_party_name(self):
        """Gets the lead_party_name of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The lead_party_name of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: str
        """
        return self._lead_party_name

    @lead_party_name.setter
    def lead_party_name(self, lead_party_name):
        """Sets the lead_party_name of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param lead_party_name: The lead_party_name of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: str
        """

        self._lead_party_name = lead_party_name

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def bid_offer_pair_cashflows(self):
        """Gets the bid_offer_pair_cashflows of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The bid_offer_pair_cashflows of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs
        """
        return self._bid_offer_pair_cashflows

    @bid_offer_pair_cashflows.setter
    def bid_offer_pair_cashflows(self, bid_offer_pair_cashflows):
        """Sets the bid_offer_pair_cashflows of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param bid_offer_pair_cashflows: The bid_offer_pair_cashflows of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs
        """

        self._bid_offer_pair_cashflows = bid_offer_pair_cashflows

    @property
    def total_cashflow(self):
        """Gets the total_cashflow of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501


        :return: The total_cashflow of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_cashflow

    @total_cashflow.setter
    def total_cashflow(self, total_cashflow):
        """Sets the total_cashflow of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.


        :param total_cashflow: The total_cashflow of this InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse.  # noqa: E501
        :type: float
        """

        self._total_cashflow = total_cashflow

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementIndicativeCashflowResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'time_from': 'datetime',
        'time_to': 'datetime',
        'level_from': 'int',
        'level_to': 'int',
        'national_grid_bm_unit': 'str',
        'bm_unit': 'str'
    }

    attribute_map = {
        'dataset': 'dataset',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'time_from': 'timeFrom',
        'time_to': 'timeTo',
        'level_from': 'levelFrom',
        'level_to': 'levelTo',
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'bm_unit': 'bmUnit'
    }

    def __init__(self, dataset=None, settlement_date=None, settlement_period=None, time_from=None, time_to=None, level_from=None, level_to=None, national_grid_bm_unit=None, bm_unit=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._settlement_date = None
        self._settlement_period = None
        self._time_from = None
        self._time_to = None
        self._level_from = None
        self._level_to = None
        self._national_grid_bm_unit = None
        self._bm_unit = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if time_from is not None:
            self.time_from = time_from
        if time_to is not None:
            self.time_to = time_to
        if level_from is not None:
            self.level_from = level_from
        if level_to is not None:
            self.level_to = level_to
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if bm_unit is not None:
            self.bm_unit = bm_unit

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param dataset: The dataset of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def time_from(self):
        """Gets the time_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The time_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: datetime
        """
        return self._time_from

    @time_from.setter
    def time_from(self, time_from):
        """Sets the time_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param time_from: The time_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: datetime
        """

        self._time_from = time_from

    @property
    def time_to(self):
        """Gets the time_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The time_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: datetime
        """
        return self._time_to

    @time_to.setter
    def time_to(self, time_to):
        """Sets the time_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param time_to: The time_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: datetime
        """

        self._time_to = time_to

    @property
    def level_from(self):
        """Gets the level_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The level_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: int
        """
        return self._level_from

    @level_from.setter
    def level_from(self, level_from):
        """Sets the level_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param level_from: The level_from of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: int
        """

        self._level_from = level_from

    @property
    def level_to(self):
        """Gets the level_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The level_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: int
        """
        return self._level_to

    @level_to.setter
    def level_to(self, level_to):
        """Sets the level_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param level_to: The level_to of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: int
        """

        self._level_to = level_to

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingPhysicalDatasetRowsPhysicalNotificationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period_from': 'int',
        'settlement_period_to': 'int',
        'time_from': 'datetime',
        'time_to': 'datetime',
        'level_from': 'int',
        'level_to': 'int',
        'national_grid_bm_unit': 'str',
        'bm_unit': 'str',
        'acceptance_number': 'int',
        'acceptance_time': 'datetime',
        'deemed_bo_flag': 'bool',
        'so_flag': 'bool',
        'stor_flag': 'bool',
        'rr_flag': 'bool'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period_from': 'settlementPeriodFrom',
        'settlement_period_to': 'settlementPeriodTo',
        'time_from': 'timeFrom',
        'time_to': 'timeTo',
        'level_from': 'levelFrom',
        'level_to': 'levelTo',
        'national_grid_bm_unit': 'nationalGridBmUnit',
        'bm_unit': 'bmUnit',
        'acceptance_number': 'acceptanceNumber',
        'acceptance_time': 'acceptanceTime',
        'deemed_bo_flag': 'deemedBoFlag',
        'so_flag': 'soFlag',
        'stor_flag': 'storFlag',
        'rr_flag': 'rrFlag'
    }

    def __init__(self, settlement_date=None, settlement_period_from=None, settlement_period_to=None, time_from=None, time_to=None, level_from=None, level_to=None, national_grid_bm_unit=None, bm_unit=None, acceptance_number=None, acceptance_time=None, deemed_bo_flag=None, so_flag=None, stor_flag=None, rr_flag=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period_from = None
        self._settlement_period_to = None
        self._time_from = None
        self._time_to = None
        self._level_from = None
        self._level_to = None
        self._national_grid_bm_unit = None
        self._bm_unit = None
        self._acceptance_number = None
        self._acceptance_time = None
        self._deemed_bo_flag = None
        self._so_flag = None
        self._stor_flag = None
        self._rr_flag = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period_from is not None:
            self.settlement_period_from = settlement_period_from
        if settlement_period_to is not None:
            self.settlement_period_to = settlement_period_to
        if time_from is not None:
            self.time_from = time_from
        if time_to is not None:
            self.time_to = time_to
        if level_from is not None:
            self.level_from = level_from
        if level_to is not None:
            self.level_to = level_to
        if national_grid_bm_unit is not None:
            self.national_grid_bm_unit = national_grid_bm_unit
        if bm_unit is not None:
            self.bm_unit = bm_unit
        if acceptance_number is not None:
            self.acceptance_number = acceptance_number
        if acceptance_time is not None:
            self.acceptance_time = acceptance_time
        if deemed_bo_flag is not None:
            self.deemed_bo_flag = deemed_bo_flag
        if so_flag is not None:
            self.so_flag = so_flag
        if stor_flag is not None:
            self.stor_flag = stor_flag
        if rr_flag is not None:
            self.rr_flag = rr_flag

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period_from(self):
        """Gets the settlement_period_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The settlement_period_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period_from

    @settlement_period_from.setter
    def settlement_period_from(self, settlement_period_from):
        """Sets the settlement_period_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param settlement_period_from: The settlement_period_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period_from = settlement_period_from

    @property
    def settlement_period_to(self):
        """Gets the settlement_period_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The settlement_period_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period_to

    @settlement_period_to.setter
    def settlement_period_to(self, settlement_period_to):
        """Sets the settlement_period_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param settlement_period_to: The settlement_period_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period_to = settlement_period_to

    @property
    def time_from(self):
        """Gets the time_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The time_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_from

    @time_from.setter
    def time_from(self, time_from):
        """Sets the time_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param time_from: The time_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: datetime
        """

        self._time_from = time_from

    @property
    def time_to(self):
        """Gets the time_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The time_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_to

    @time_to.setter
    def time_to(self, time_to):
        """Sets the time_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param time_to: The time_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: datetime
        """

        self._time_to = time_to

    @property
    def level_from(self):
        """Gets the level_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The level_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: int
        """
        return self._level_from

    @level_from.setter
    def level_from(self, level_from):
        """Sets the level_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param level_from: The level_from of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: int
        """

        self._level_from = level_from

    @property
    def level_to(self):
        """Gets the level_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The level_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: int
        """
        return self._level_to

    @level_to.setter
    def level_to(self, level_to):
        """Sets the level_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param level_to: The level_to of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: int
        """

        self._level_to = level_to

    @property
    def national_grid_bm_unit(self):
        """Gets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: str
        """
        return self._national_grid_bm_unit

    @national_grid_bm_unit.setter
    def national_grid_bm_unit(self, national_grid_bm_unit):
        """Sets the national_grid_bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param national_grid_bm_unit: The national_grid_bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: str
        """

        self._national_grid_bm_unit = national_grid_bm_unit

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    @property
    def acceptance_number(self):
        """Gets the acceptance_number of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The acceptance_number of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: int
        """
        return self._acceptance_number

    @acceptance_number.setter
    def acceptance_number(self, acceptance_number):
        """Sets the acceptance_number of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param acceptance_number: The acceptance_number of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: int
        """

        self._acceptance_number = acceptance_number

    @property
    def acceptance_time(self):
        """Gets the acceptance_time of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The acceptance_time of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._acceptance_time

    @acceptance_time.setter
    def acceptance_time(self, acceptance_time):
        """Sets the acceptance_time of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param acceptance_time: The acceptance_time of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: datetime
        """

        self._acceptance_time = acceptance_time

    @property
    def deemed_bo_flag(self):
        """Gets the deemed_bo_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The deemed_bo_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._deemed_bo_flag

    @deemed_bo_flag.setter
    def deemed_bo_flag(self, deemed_bo_flag):
        """Sets the deemed_bo_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param deemed_bo_flag: The deemed_bo_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: bool
        """

        self._deemed_bo_flag = deemed_bo_flag

    @property
    def so_flag(self):
        """Gets the so_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The so_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._so_flag

    @so_flag.setter
    def so_flag(self, so_flag):
        """Sets the so_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param so_flag: The so_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: bool
        """

        self._so_flag = so_flag

    @property
    def stor_flag(self):
        """Gets the stor_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The stor_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._stor_flag

    @stor_flag.setter
    def stor_flag(self, stor_flag):
        """Sets the stor_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param stor_flag: The stor_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: bool
        """

        self._stor_flag = stor_flag

    @property
    def rr_flag(self):
        """Gets the rr_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501


        :return: The rr_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._rr_flag

    @rr_flag.setter
    def rr_flag(self, rr_flag):
        """Sets the rr_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.


        :param rr_flag: The rr_flag of this InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse.  # noqa: E501
        :type: bool
        """

        self._rr_flag = rr_flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingBidOfferAcceptancesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesDemandForecastDemandForecastWeekly(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'publish_time': 'datetime',
        'transmission_system_demand': 'int',
        'national_demand': 'int',
        'forecast_week': 'int',
        'forecast_year': 'int',
        'week_start_date': 'date'
    }

    attribute_map = {
        'publish_time': 'publishTime',
        'transmission_system_demand': 'transmissionSystemDemand',
        'national_demand': 'nationalDemand',
        'forecast_week': 'forecastWeek',
        'forecast_year': 'forecastYear',
        'week_start_date': 'weekStartDate'
    }

    def __init__(self, publish_time=None, transmission_system_demand=None, national_demand=None, forecast_week=None, forecast_year=None, week_start_date=None):  # noqa: E501
        """InsightsApiModelsResponsesDemandForecastDemandForecastWeekly - a model defined in Swagger"""  # noqa: E501
        self._publish_time = None
        self._transmission_system_demand = None
        self._national_demand = None
        self._forecast_week = None
        self._forecast_year = None
        self._week_start_date = None
        self.discriminator = None
        if publish_time is not None:
            self.publish_time = publish_time
        if transmission_system_demand is not None:
            self.transmission_system_demand = transmission_system_demand
        if national_demand is not None:
            self.national_demand = national_demand
        if forecast_week is not None:
            self.forecast_week = forecast_week
        if forecast_year is not None:
            self.forecast_year = forecast_year
        if week_start_date is not None:
            self.week_start_date = week_start_date

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def transmission_system_demand(self):
        """Gets the transmission_system_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The transmission_system_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: int
        """
        return self._transmission_system_demand

    @transmission_system_demand.setter
    def transmission_system_demand(self, transmission_system_demand):
        """Sets the transmission_system_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param transmission_system_demand: The transmission_system_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: int
        """

        self._transmission_system_demand = transmission_system_demand

    @property
    def national_demand(self):
        """Gets the national_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The national_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: int
        """
        return self._national_demand

    @national_demand.setter
    def national_demand(self, national_demand):
        """Sets the national_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param national_demand: The national_demand of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: int
        """

        self._national_demand = national_demand

    @property
    def forecast_week(self):
        """Gets the forecast_week of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The forecast_week of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: int
        """
        return self._forecast_week

    @forecast_week.setter
    def forecast_week(self, forecast_week):
        """Sets the forecast_week of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param forecast_week: The forecast_week of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: int
        """

        self._forecast_week = forecast_week

    @property
    def forecast_year(self):
        """Gets the forecast_year of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The forecast_year of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: int
        """
        return self._forecast_year

    @forecast_year.setter
    def forecast_year(self, forecast_year):
        """Sets the forecast_year of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param forecast_year: The forecast_year of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: int
        """

        self._forecast_year = forecast_year

    @property
    def week_start_date(self):
        """Gets the week_start_date of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501


        :return: The week_start_date of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :rtype: date
        """
        return self._week_start_date

    @week_start_date.setter
    def week_start_date(self, week_start_date):
        """Sets the week_start_date of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.


        :param week_start_date: The week_start_date of this InsightsApiModelsResponsesDemandForecastDemandForecastWeekly.  # noqa: E501
        :type: date
        """

        self._week_start_date = week_start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesDemandForecastDemandForecastWeekly, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesDemandForecastDemandForecastWeekly):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'document_id': 'str',
        'publish_time': 'datetime',
        'effective_from': 'date',
        'psr_type': 'str',
        'registered_resource_eic_code': 'str',
        'registered_resource_name': 'str',
        'bm_unit': 'str',
        'voltage_limit': 'float',
        'installed_capacity': 'float'
    }

    attribute_map = {
        'dataset': 'dataset',
        'document_id': 'documentId',
        'publish_time': 'publishTime',
        'effective_from': 'effectiveFrom',
        'psr_type': 'psrType',
        'registered_resource_eic_code': 'registeredResourceEicCode',
        'registered_resource_name': 'registeredResourceName',
        'bm_unit': 'bmUnit',
        'voltage_limit': 'voltageLimit',
        'installed_capacity': 'installedCapacity'
    }

    def __init__(self, dataset=None, document_id=None, publish_time=None, effective_from=None, psr_type=None, registered_resource_eic_code=None, registered_resource_name=None, bm_unit=None, voltage_limit=None, installed_capacity=None):  # noqa: E501
        """InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._document_id = None
        self._publish_time = None
        self._effective_from = None
        self._psr_type = None
        self._registered_resource_eic_code = None
        self._registered_resource_name = None
        self._bm_unit = None
        self._voltage_limit = None
        self._installed_capacity = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if document_id is not None:
            self.document_id = document_id
        if publish_time is not None:
            self.publish_time = publish_time
        if effective_from is not None:
            self.effective_from = effective_from
        if psr_type is not None:
            self.psr_type = psr_type
        if registered_resource_eic_code is not None:
            self.registered_resource_eic_code = registered_resource_eic_code
        if registered_resource_name is not None:
            self.registered_resource_name = registered_resource_name
        if bm_unit is not None:
            self.bm_unit = bm_unit
        if voltage_limit is not None:
            self.voltage_limit = voltage_limit
        if installed_capacity is not None:
            self.installed_capacity = installed_capacity

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param dataset: The dataset of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def document_id(self):
        """Gets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param document_id: The document_id of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def effective_from(self):
        """Gets the effective_from of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The effective_from of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: date
        """
        return self._effective_from

    @effective_from.setter
    def effective_from(self, effective_from):
        """Sets the effective_from of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param effective_from: The effective_from of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: date
        """

        self._effective_from = effective_from

    @property
    def psr_type(self):
        """Gets the psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._psr_type

    @psr_type.setter
    def psr_type(self, psr_type):
        """Sets the psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param psr_type: The psr_type of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._psr_type = psr_type

    @property
    def registered_resource_eic_code(self):
        """Gets the registered_resource_eic_code of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The registered_resource_eic_code of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._registered_resource_eic_code

    @registered_resource_eic_code.setter
    def registered_resource_eic_code(self, registered_resource_eic_code):
        """Sets the registered_resource_eic_code of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param registered_resource_eic_code: The registered_resource_eic_code of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._registered_resource_eic_code = registered_resource_eic_code

    @property
    def registered_resource_name(self):
        """Gets the registered_resource_name of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The registered_resource_name of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._registered_resource_name

    @registered_resource_name.setter
    def registered_resource_name(self, registered_resource_name):
        """Sets the registered_resource_name of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param registered_resource_name: The registered_resource_name of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._registered_resource_name = registered_resource_name

    @property
    def bm_unit(self):
        """Gets the bm_unit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The bm_unit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._bm_unit

    @bm_unit.setter
    def bm_unit(self, bm_unit):
        """Sets the bm_unit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param bm_unit: The bm_unit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: str
        """

        self._bm_unit = bm_unit

    @property
    def voltage_limit(self):
        """Gets the voltage_limit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The voltage_limit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._voltage_limit

    @voltage_limit.setter
    def voltage_limit(self, voltage_limit):
        """Sets the voltage_limit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param voltage_limit: The voltage_limit of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: float
        """

        self._voltage_limit = voltage_limit

    @property
    def installed_capacity(self):
        """Gets the installed_capacity of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501


        :return: The installed_capacity of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._installed_capacity

    @installed_capacity.setter
    def installed_capacity(self, installed_capacity):
        """Sets the installed_capacity of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.


        :param installed_capacity: The installed_capacity of this InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow.  # noqa: E501
        :type: float
        """

        self._installed_capacity = installed_capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesTransparencyDatasetRowsIgcpuDatasetRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class RollingSystemDemandApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def generation_outturn_get(self, **kwargs):  # noqa: E501
        """Total generation outturn (FUELINST)  # noqa: E501

        This endpoint provides the total generation outturn across all fuel types, derived by summing generation  of all categories from the Generation by Fuel Type report.                This data can be used as a proxy for rolling system demand.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generation_outturn_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnRollingSystemDemand
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generation_outturn_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.generation_outturn_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def generation_outturn_get_with_http_info(self, **kwargs):  # noqa: E501
        """Total generation outturn (FUELINST)  # noqa: E501

        This endpoint provides the total generation outturn across all fuel types, derived by summing generation  of all categories from the Generation by Fuel Type report.                This data can be used as a proxy for rolling system demand.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generation_outturn_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from:
        :param datetime to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnRollingSystemDemand
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generation_outturn_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/generation/outturn', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandOutturnRollingSystemDemand',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
